@@ -1,7 +1,10 @@
 '''
 ## CDK Graph (`@aws-prototyping-sdk/cdk-graph`)
 
-![experimental](http://badges.github.io/stability-badges/dist/experimental.svg)
+![experimental](https://img.shields.io/badge/stability-experimental-orange.svg)
+![alpha](https://img.shields.io/badge/version-alpha-red.svg)
+[![API Documetnation](https://img.shields.io/badge/view-API_Documentation-blue.svg)](https://aws.github.io/aws-prototyping-sdk/typescript/cdk-graph/index.html)
+[![Source Code](https://img.shields.io/badge/view-Source_Code-blue.svg)](https://github.com/aws/aws-prototyping-sdk/tree/mainline/packages/cdk-graph)
 
 > More comprehensive documentation to come as this package stabilizes
 
@@ -15,6 +18,18 @@ This package provides the following functionality:
 
 The goal of this framework is to enable bespoke tooling to be built without having to first traverse the CDK Tree and Metadata to build a graph. Projects like [cdk-dia](https://github.com/pistazie/cdk-dia) generate a bespoke in-memory graph that is then utilized to generate diagrams; while the diagram generation is the core value it must first have a graph to act upon and currently is required to generate this undifferentiated graph to provide its diagrams. By standardizing on the graph interface necessary to build complex tooling, we can more rapidly build new tooling that focuses on its core value.
 
+---
+
+
+### Available Plugins
+
+| Name | Description | Screenshot | Links |
+|--- | --- | --- | --- |
+| **Diagram** | Generate cloud infrastructure diagrams from cdk graph | <img src="https://github.com/aws/aws-prototyping-sdk/blob/mainline/packages/cdk-graph-plugin-diagram/docs/examples/default.png?raw=true" style="max-width:200px;max-height:200px" /> | [![API Documetnation](https://img.shields.io/badge/view-API_Documentation-blue.svg)](https://aws.github.io/aws-prototyping-sdk/typescript/cdk-graph/index.html) [![Source Code](https://img.shields.io/badge/view-Source_Code-blue.svg)](https://github.com/aws/aws-prototyping-sdk/tree/mainline/packages/cdk-graph) |
+
+---
+
+
 ### Quick Start
 
 #### Instrument CDK App with CdkGraph
@@ -52,7 +67,10 @@ new CdkGraph(app, {
 });
 ```
 
-#### Config
+---
+
+
+### Config
 
 Configuration is supported through the `.cdkgraphrc.js` and depending on the plugin, through passing config to the plugin instance.
 
@@ -94,6 +112,9 @@ new CdkGraph(app, {
 });
 ```
 
+---
+
+
 ### Plugin Interface
 
 ```python
@@ -313,7 +334,12 @@ class CdkGraph(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraph.__init__)
+            def stub(
+                root: constructs.Construct,
+                props: typing.Optional[ICdkGraphProps] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument root", value=root, expected_type=type_hints["root"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         jsii.create(self.__class__, self, [root, props])
@@ -417,7 +443,16 @@ class CdkGraphArtifact:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraphArtifact.__init__)
+            def stub(
+                *,
+                filename: builtins.str,
+                filepath: builtins.str,
+                id: builtins.str,
+                source: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument filename", value=filename, expected_type=type_hints["filename"])
             check_type(argname="argument filepath", value=filepath, expected_type=type_hints["filepath"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
@@ -524,7 +559,9 @@ class CdkGraphConfig:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraphConfig.__init__)
+            def stub(*, outdir: typing.Optional[builtins.str] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
         self._values: typing.Dict[str, typing.Any] = {}
         if outdir is not None:
@@ -574,7 +611,9 @@ class CdkGraphContext(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraphContext.__init__)
+            def stub(store: _Store_6b467276, outdir: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument store", value=store, expected_type=type_hints["store"])
             check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
         jsii.create(self.__class__, self, [store, outdir])
@@ -589,7 +628,9 @@ class CdkGraphContext(
         :throws: Error is artifact does not exist
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraphContext.get_artifact)
+            def stub(id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(CdkGraphArtifact, jsii.invoke(self, "getArtifact", [id]))
 
@@ -602,7 +643,9 @@ class CdkGraphContext(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraphContext.has_artifact_file)
+            def stub(filename: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument filename", value=filename, expected_type=type_hints["filename"])
         return typing.cast(builtins.bool, jsii.invoke(self, "hasArtifactFile", [filename]))
 
@@ -629,7 +672,14 @@ class CdkGraphContext(
         :throws: Error is artifact id or filename already exists
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraphContext.log_artifact)
+            def stub(
+                source: typing.Union[CdkGraph, ICdkGraphPlugin],
+                id: builtins.str,
+                filepath: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument filepath", value=filepath, expected_type=type_hints["filepath"])
@@ -656,7 +706,15 @@ class CdkGraphContext(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CdkGraphContext.write_artifact)
+            def stub(
+                source: typing.Union[CdkGraph, ICdkGraphPlugin],
+                id: builtins.str,
+                filename: builtins.str,
+                data: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument filename", value=filename, expected_type=type_hints["filename"])
@@ -732,7 +790,9 @@ class ConstructInfo:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ConstructInfo.__init__)
+            def stub(*, fqn: builtins.str, version: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument fqn", value=fqn, expected_type=type_hints["fqn"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -821,6 +881,10 @@ class ConstructInfoFqnEnum(enum.Enum):
     '''
     :stability: experimental
     '''
+    LAMBDA = "LAMBDA"
+    '''
+    :stability: experimental
+    '''
     CFN_LAMBDA = "CFN_LAMBDA"
     '''
     :stability: experimental
@@ -841,6 +905,10 @@ class ConstructInfoFqnEnum(enum.Enum):
     '''
     :stability: experimental
     '''
+    LAMBDA_BASE = "LAMBDA_BASE"
+    '''
+    :stability: experimental
+    '''
     ASSET_STAGING = "ASSET_STAGING"
     '''
     :stability: experimental
@@ -965,6 +1033,11 @@ class FilterPreset(enum.Enum):
 
     :stability: experimental
     '''
+    NON_EXTRANEOUS = "NON_EXTRANEOUS"
+    '''(experimental) Collapses extraneous nodes to parent and prunes extraneous edges.
+
+    :stability: experimental
+    '''
 
 
 @jsii.enum(jsii_type="@aws-prototyping-sdk/cdk-graph.FilterStrategy")
@@ -1048,6 +1121,13 @@ class FlagEnum(enum.Enum):
 
     :stability: experimental
     '''
+    WRAPPED_CFN_RESOURCE = "WRAPPED_CFN_RESOURCE"
+    '''(experimental) Indicates that cfn resource has equivalent cdk resource wrapper.
+
+    (eg: Lambda => CfnLambda)
+
+    :stability: experimental
+    '''
 
 
 @jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.ICdkGraphPlugin")
@@ -1198,7 +1278,9 @@ class _ICdkGraphPluginProxy:
     @bind.setter
     def bind(self, value: "IGraphPluginBindCallback") -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ICdkGraphPlugin, "bind").fset)
+            def stub(value: IGraphPluginBindCallback) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "bind", value)
 
@@ -1217,7 +1299,9 @@ class _ICdkGraphPluginProxy:
     @inspect.setter
     def inspect(self, value: typing.Optional["IGraphVisitorCallback"]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ICdkGraphPlugin, "inspect").fset)
+            def stub(value: typing.Optional[IGraphVisitorCallback]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "inspect", value)
 
@@ -1238,7 +1322,9 @@ class _ICdkGraphPluginProxy:
     @report.setter
     def report(self, value: typing.Optional["IGraphReportCallback"]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ICdkGraphPlugin, "report").fset)
+            def stub(value: typing.Optional[IGraphReportCallback]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "report", value)
 
@@ -1256,7 +1342,9 @@ class _ICdkGraphPluginProxy:
     @synthesize.setter
     def synthesize(self, value: typing.Optional["IGraphSynthesizeCallback"]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ICdkGraphPlugin, "synthesize").fset)
+            def stub(value: typing.Optional[IGraphSynthesizeCallback]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "synthesize", value)
 
@@ -1309,7 +1397,9 @@ class _ICdkGraphPropsProxy:
     @plugins.setter
     def plugins(self, value: typing.Optional[typing.List[ICdkGraphPlugin]]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ICdkGraphProps, "plugins").fset)
+            def stub(value: typing.Optional[typing.List[ICdkGraphPlugin]]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "plugins", value)
 
@@ -1344,9 +1434,9 @@ class _ICounterRecordProxy:
 typing.cast(typing.Any, ICounterRecord).__jsii_proxy_class__ = lambda : _ICounterRecordProxy
 
 
-@jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.IFilterRootCallback")
-class IFilterRootCallback(typing_extensions.Protocol):
-    '''(experimental) Determines root node of filter plan.
+@jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.IFilterFocusCallback")
+class IFilterFocusCallback(typing_extensions.Protocol):
+    '''(experimental) Determines focus node of filter plan.
 
     :stability: experimental
     '''
@@ -1354,17 +1444,17 @@ class IFilterRootCallback(typing_extensions.Protocol):
     pass
 
 
-class _IFilterRootCallbackProxy:
-    '''(experimental) Determines root node of filter plan.
+class _IFilterFocusCallbackProxy:
+    '''(experimental) Determines focus node of filter plan.
 
     :stability: experimental
     '''
 
-    __jsii_type__: typing.ClassVar[str] = "@aws-prototyping-sdk/cdk-graph.IFilterRootCallback"
+    __jsii_type__: typing.ClassVar[str] = "@aws-prototyping-sdk/cdk-graph.IFilterFocusCallback"
     pass
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, IFilterRootCallback).__jsii_proxy_class__ = lambda : _IFilterRootCallbackProxy
+typing.cast(typing.Any, IFilterFocusCallback).__jsii_proxy_class__ = lambda : _IFilterFocusCallbackProxy
 
 
 @jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.IGraphFilter")
@@ -1374,6 +1464,21 @@ class IGraphFilter(typing_extensions.Protocol):
     :stability: experimental
     '''
 
+    @builtins.property
+    @jsii.member(jsii_name="allNodes")
+    def all_nodes(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Indicates that all nodes will be filtered, rather than just Resource and CfnResource nodes.
+
+        By enabling this, all Stages, Stacks, and structural construct boundaries will be filtered as well.
+        In general, most users intent is to operate against resources and desire to preserve structural groupings,
+        which is common in most Cfn/Cdk based filtering where inputs are "include" lists.
+
+        Defaults to value of containing {@link IGraphFilterPlan.allNodes}
+
+        :stability: experimental
+        '''
+        ...
+
     @builtins.property
     @jsii.member(jsii_name="edge")
     def edge(self) -> typing.Optional[_IEdgePredicate_786afb09]:
@@ -1430,6 +1535,21 @@ class _IGraphFilterProxy:
 
     __jsii_type__: typing.ClassVar[str] = "@aws-prototyping-sdk/cdk-graph.IGraphFilter"
 
+    @builtins.property
+    @jsii.member(jsii_name="allNodes")
+    def all_nodes(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Indicates that all nodes will be filtered, rather than just Resource and CfnResource nodes.
+
+        By enabling this, all Stages, Stacks, and structural construct boundaries will be filtered as well.
+        In general, most users intent is to operate against resources and desire to preserve structural groupings,
+        which is common in most Cfn/Cdk based filtering where inputs are "include" lists.
+
+        Defaults to value of containing {@link IGraphFilterPlan.allNodes}
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "allNodes"))
+
     @builtins.property
     @jsii.member(jsii_name="edge")
     def edge(self) -> typing.Optional[_IEdgePredicate_786afb09]:
@@ -1505,8 +1625,10 @@ class IGraphFilterPlan(typing_extensions.Protocol):
 
     @builtins.property
     @jsii.member(jsii_name="filters")
-    def filters(self) -> typing.Optional[typing.List[IGraphFilter]]:
-        '''(experimental) Node/Edge predicate filters to apply to the graph.
+    def filters(
+        self,
+    ) -> typing.Optional[typing.List[typing.Union[IGraphFilter, "IGraphStoreFilter"]]]:
+        '''(experimental) Ordered list of {@link IGraphFilter} and {@link IGraphStoreFilter} filters to apply to the store.
 
         - Filters are applied *after* the preset filtering is applied if present.
         - Filters are applied sequentially against all nodes, as opposed to IAspect.visitor pattern
@@ -1517,14 +1639,11 @@ class IGraphFilterPlan(typing_extensions.Protocol):
         ...
 
     @builtins.property
-    @jsii.member(jsii_name="hoistRoot")
-    def hoist_root(self) -> typing.Optional[builtins.bool]:
-        '''(experimental) Indicates if ancestral containers are preserved (eg: Stages, Stack).
-
-        If ``true``, the "root" will be hoisted to the graph root and all ancestors will be pruned.
-        If ``false``, the "root" will be left in-place, while all siblings and non-scope ancestors will be pruned.
-
-        :default: false
+    @jsii.member(jsii_name="focus")
+    def focus(
+        self,
+    ) -> typing.Optional[typing.Union[_Node_ddadac9d, IFilterFocusCallback, "IGraphFilterPlanFocusConfig"]]:
+        '''(experimental) Config to focus the graph on specific node.
 
         :stability: experimental
         '''
@@ -1550,17 +1669,6 @@ class IGraphFilterPlan(typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property
-    @jsii.member(jsii_name="root")
-    def root(
-        self,
-    ) -> typing.Optional[typing.Union[_Node_ddadac9d, IFilterRootCallback]]:
-        '''(experimental) The root node or resolver to determine the filtering root.
-
-        :stability: experimental
-        '''
-        ...
-
 
 class _IGraphFilterPlanProxy:
     '''(experimental) Graph filter plan.
@@ -1587,8 +1695,10 @@ class _IGraphFilterPlanProxy:
 
     @builtins.property
     @jsii.member(jsii_name="filters")
-    def filters(self) -> typing.Optional[typing.List[IGraphFilter]]:
-        '''(experimental) Node/Edge predicate filters to apply to the graph.
+    def filters(
+        self,
+    ) -> typing.Optional[typing.List[typing.Union[IGraphFilter, "IGraphStoreFilter"]]]:
+        '''(experimental) Ordered list of {@link IGraphFilter} and {@link IGraphStoreFilter} filters to apply to the store.
 
         - Filters are applied *after* the preset filtering is applied if present.
         - Filters are applied sequentially against all nodes, as opposed to IAspect.visitor pattern
@@ -1596,21 +1706,18 @@ class _IGraphFilterPlanProxy:
 
         :stability: experimental
         '''
-        return typing.cast(typing.Optional[typing.List[IGraphFilter]], jsii.get(self, "filters"))
+        return typing.cast(typing.Optional[typing.List[typing.Union[IGraphFilter, "IGraphStoreFilter"]]], jsii.get(self, "filters"))
 
     @builtins.property
-    @jsii.member(jsii_name="hoistRoot")
-    def hoist_root(self) -> typing.Optional[builtins.bool]:
-        '''(experimental) Indicates if ancestral containers are preserved (eg: Stages, Stack).
-
-        If ``true``, the "root" will be hoisted to the graph root and all ancestors will be pruned.
-        If ``false``, the "root" will be left in-place, while all siblings and non-scope ancestors will be pruned.
-
-        :default: false
+    @jsii.member(jsii_name="focus")
+    def focus(
+        self,
+    ) -> typing.Optional[typing.Union[_Node_ddadac9d, IFilterFocusCallback, "IGraphFilterPlanFocusConfig"]]:
+        '''(experimental) Config to focus the graph on specific node.
 
         :stability: experimental
         '''
-        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "hoistRoot"))
+        return typing.cast(typing.Optional[typing.Union[_Node_ddadac9d, IFilterFocusCallback, "IGraphFilterPlanFocusConfig"]], jsii.get(self, "focus"))
 
     @builtins.property
     @jsii.member(jsii_name="order")
@@ -1632,19 +1739,72 @@ class _IGraphFilterPlanProxy:
         '''
         return typing.cast(typing.Optional[FilterPreset], jsii.get(self, "preset"))
 
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IGraphFilterPlan).__jsii_proxy_class__ = lambda : _IGraphFilterPlanProxy
+
+
+@jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.IGraphFilterPlanFocusConfig")
+class IGraphFilterPlanFocusConfig(typing_extensions.Protocol):
+    '''
+    :stability: experimental
+    '''
+
     @builtins.property
-    @jsii.member(jsii_name="root")
-    def root(
-        self,
-    ) -> typing.Optional[typing.Union[_Node_ddadac9d, IFilterRootCallback]]:
-        '''(experimental) The root node or resolver to determine the filtering root.
+    @jsii.member(jsii_name="node")
+    def node(self) -> typing.Union[_Node_ddadac9d, IFilterFocusCallback]:
+        '''(experimental) The node or resolver to determine the node to focus on.
 
         :stability: experimental
         '''
-        return typing.cast(typing.Optional[typing.Union[_Node_ddadac9d, IFilterRootCallback]], jsii.get(self, "root"))
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="noHoist")
+    def no_hoist(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Indicates if ancestral containers are preserved (eg: Stages, Stack).
+
+        If ``false``, the "focused node" will be hoisted to the graph root and all ancestors will be pruned.
+        If ``true``, the "focused" will be left in-place, while all siblings and non-scope ancestors will be pruned.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        ...
+
+
+class _IGraphFilterPlanFocusConfigProxy:
+    '''
+    :stability: experimental
+    '''
+
+    __jsii_type__: typing.ClassVar[str] = "@aws-prototyping-sdk/cdk-graph.IGraphFilterPlanFocusConfig"
+
+    @builtins.property
+    @jsii.member(jsii_name="node")
+    def node(self) -> typing.Union[_Node_ddadac9d, IFilterFocusCallback]:
+        '''(experimental) The node or resolver to determine the node to focus on.
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Union[_Node_ddadac9d, IFilterFocusCallback], jsii.get(self, "node"))
+
+    @builtins.property
+    @jsii.member(jsii_name="noHoist")
+    def no_hoist(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Indicates if ancestral containers are preserved (eg: Stages, Stack).
+
+        If ``false``, the "focused node" will be hoisted to the graph root and all ancestors will be pruned.
+        If ``true``, the "focused" will be left in-place, while all siblings and non-scope ancestors will be pruned.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "noHoist"))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, IGraphFilterPlan).__jsii_proxy_class__ = lambda : _IGraphFilterPlanProxy
+typing.cast(typing.Any, IGraphFilterPlanFocusConfig).__jsii_proxy_class__ = lambda : _IGraphFilterPlanFocusConfigProxy
 
 
 @jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.IGraphPluginBindCallback")
@@ -1693,6 +1853,29 @@ class _IGraphReportCallbackProxy:
 typing.cast(typing.Any, IGraphReportCallback).__jsii_proxy_class__ = lambda : _IGraphReportCallbackProxy
 
 
+@jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.IGraphStoreFilter")
+class IGraphStoreFilter(typing_extensions.Protocol):
+    '''(experimental) Store filter callback interface used to perform filtering operations directly against the store, as opposed to using {@link IGraphFilter} definitions.
+
+    :stability: experimental
+    '''
+
+    pass
+
+
+class _IGraphStoreFilterProxy:
+    '''(experimental) Store filter callback interface used to perform filtering operations directly against the store, as opposed to using {@link IGraphFilter} definitions.
+
+    :stability: experimental
+    '''
+
+    __jsii_type__: typing.ClassVar[str] = "@aws-prototyping-sdk/cdk-graph.IGraphStoreFilter"
+    pass
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IGraphStoreFilter).__jsii_proxy_class__ = lambda : _IGraphStoreFilterProxy
+
+
 @jsii.interface(jsii_type="@aws-prototyping-sdk/cdk-graph.IGraphSynthesizeCallback")
 class IGraphSynthesizeCallback(typing_extensions.Protocol):
     '''(experimental) Callback signature for graph ``Plugin.synthesize`` operation.
@@ -1792,7 +1975,21 @@ class InferredNodeProps(_Entity_794b3e11):
         if isinstance(construct_info, dict):
             construct_info = ConstructInfo(**construct_info)
         if __debug__:
-            type_hints = typing.get_type_hints(InferredNodeProps.__init__)
+            def stub(
+                *,
+                uuid: builtins.str,
+                attributes: typing.Optional[typing.Union[_Attributes_b47661e3, typing.Dict[str, typing.Any]]] = None,
+                flags: typing.Optional[typing.Sequence[FlagEnum]] = None,
+                metadata: typing.Optional[typing.Sequence[typing.Union[constructs.MetadataEntry, typing.Dict[str, typing.Any]]]] = None,
+                tags: typing.Optional[typing.Union[_Tags_cf30c388, typing.Dict[str, typing.Any]]] = None,
+                dependencies: typing.Sequence[builtins.str],
+                unresolved_references: typing.Sequence[typing.Union[UnresolvedReference, typing.Dict[str, typing.Any]]],
+                cfn_type: typing.Optional[builtins.str] = None,
+                construct_info: typing.Optional[typing.Union[ConstructInfo, typing.Dict[str, typing.Any]]] = None,
+                logical_id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
             check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
             check_type(argname="argument flags", value=flags, expected_type=type_hints["flags"])
@@ -2064,7 +2261,15 @@ class UnresolvedReference:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(UnresolvedReference.__init__)
+            def stub(
+                *,
+                reference_type: ReferenceTypeEnum,
+                source: builtins.str,
+                target: builtins.str,
+                value: typing.Optional[typing.Union[builtins.str, jsii.Number, builtins.bool, typing.Union[_PlainObject_c976ebcc, typing.Dict[str, typing.Any]], typing.Sequence[typing.Union[builtins.str, jsii.Number, builtins.bool, typing.Union[_PlainObject_c976ebcc, typing.Dict[str, typing.Any]]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument reference_type", value=reference_type, expected_type=type_hints["reference_type"])
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
@@ -2144,11 +2349,13 @@ __all__ = [
     "ICdkGraphPlugin",
     "ICdkGraphProps",
     "ICounterRecord",
-    "IFilterRootCallback",
+    "IFilterFocusCallback",
     "IGraphFilter",
     "IGraphFilterPlan",
+    "IGraphFilterPlanFocusConfig",
     "IGraphPluginBindCallback",
     "IGraphReportCallback",
+    "IGraphStoreFilter",
     "IGraphSynthesizeCallback",
     "IGraphVisitorCallback",
     "InferredNodeProps",
